from functools import wraps

from pydantic import ValidationError

from src.core.entity.ResponseTypes import ResponseTypes


def check_params(Model):
	def decorator(func):
		@wraps(func)
		def wrapper(*args, **kwargs):
			params = kwargs.get('params', None)
			if params is not None:
				try:
					Model.model_validate(params, strict=True)
				except ValidationError as e:
					errors = []
					for error in e.errors():
						errors.append(
							{
								'field': error['loc'][0],
								'message': error['msg'],
							}
						)
					return {
						'type': ResponseTypes.PARAMETERS_ERROR,
						'errors': errors,
					}
			return func(*args, **kwargs)

		return wrapper

	return decorator
