import os

from src.core.entity.ResponseTypes import ResponseTypes
from src.infra.api.fastapi.middleware import (
    CorrectHTTPCodeMiddleware,
    ErrorsToCamelCase,
    ResponseToCamelCase,
)
from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware

from src.infra.api.fastapi.routers import documents

app = FastAPI()

origins = list(
    filter(
        lambda url: f"{url.strip()}",
        os.environ.get("API_CORS_ORIGINS", "*").split(","),
    )
)

# Middlewares
app.add_middleware(
    CORSMiddleware,
    allow_origins=origins,
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)
app.add_middleware(CorrectHTTPCodeMiddleware)
app.add_middleware(ResponseToCamelCase)
app.add_middleware(ErrorsToCamelCase)

# Routers
app.include_router(documents.router)


@app.get("/")
async def index():
    return {
        "type": ResponseTypes.SUCCESS,
        "error": [],
        "data": "Welcome to the API. Check the documentation at /docs.",
    }
