import os
from typing import Any
from pydantic import BaseModel
from src.infra.api.fastapi.tools import (
    convert_keys_to_snake_case,
)
from fastapi import APIRouter, Depends, Request, Response
from src.core.use_case import documents_use_case
from src.infra.storage.AzureStorage import AzureStorage

router = APIRouter(
    prefix="/api/v1/documents",
    tags=["documents"],
)


class DocumentListModel(BaseModel):
    appName: Any | None = None
    clientId: Any | None = None


@router.get(
    "/",
    summary="Get list documents",
    description="Get list documents",
)
async def list_documents(
    request: Request,
    response: Response,
    query: DocumentListModel = Depends(),
) -> dict:
    storage = AzureStorage(
        account_name=os.getenv("AZURE_STORAGE_ACCOUNT_NAME", ""),
        account_key=os.getenv("AZURE_STORAGE_ACCOUNT_KEY", ""),
    )
    params = convert_keys_to_snake_case(query.dict(exclude_none=True))
    return documents_use_case.documents_list(storage=storage, params=params)
